import os
from flask import Blueprint, render_template, redirect, url_for, request, session

from web_utils.get_arg import get_arg

from data.document import Document

bp = Blueprint('admin_document', __name__, url_prefix='/admin/doc')

@bp.route('/new', methods=['GET', 'POST'])
def new():
	if request.method == 'POST':
		repo = request.form.get('repo')
		doc_name = request.form.get('doc')
		branch = request.form.get('branch')
		source_dir = request.form.get('source')
		
		if doc_name == "":
			doc_name = os.path.splitext(os.path.basename(repo))[0]
		
		clone_task = Document.clone(repo, branch, doc_name, source_dir)
		
		return render_template("admin/command_output.html", task = clone_task, next = url_for('admin_document.manage', origin = Document.encode_origin(Document.get_origin(repo)), doc_name = doc_name, branch = branch))
	else:
		return render_template("admin/document/new.html")

@bp.route('/manage/<origin>/<doc_name>/<branch>')
def manage(origin, doc_name, branch):
	return render_template("admin/document/manage.html", doc=Document(origin, doc_name, branch))

@bp.route('/build/<origin>/<doc_name>/<branch>')
def build(origin, doc_name, branch):
	doc = Document(origin, doc_name, branch)
	build_task = doc.build()
	
	return render_template("admin/command_output.html", task = build_task, next = url_for('admin_document.manage', origin = doc.encoded_origin, doc_name = doc.doc_name, branch = doc.branch))

@bp.route('/delete/<origin>/<doc_name>/<branch>')
def delete(origin, doc_name, branch):
	doc = Document(origin, doc_name, branch)
	doc.delete()
	return redirect(url_for('admin.index'), code=302)

@bp.route('/delete_invalid/<origin>/<doc_name>/<branch>')
def delete_invalid(origin, doc_name, branch):
	doc = Document(origin, doc_name, branch, allow_invalid = True)
	doc.delete_folder()
	return redirect(url_for('admin.index'), code=302)
